/*
 * Copyright (c) 2005-2010 KOM – Multimedia Communications Lab
 *
 * This file is part of Simonstrator.KOM.
 * 
 * Simonstrator.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


package de.tudarmstadt.maki.simonstrator.api.component.sis.prediction;

import de.tudarmstadt.maki.simonstrator.api.Time;
import de.tudarmstadt.maki.simonstrator.api.common.graph.INodeID;
import de.tudarmstadt.maki.simonstrator.api.component.sis.type.PredictionContainer;
import de.tudarmstadt.maki.simonstrator.api.component.sis.type.SiSType;

/**
 * @author Tobias Meuser (tobias.meuser@kom.tu-darmstadt.de)
 * @version 1.0 at 05.01.2018
 *
 */
public interface Prediction<T extends Object> {

	/**
	 * @param pNodeID
	 * @param pObservation
	 * @param pObservationTimestamp
	 * @return
	 */
	default PredictionContainer<T> predict(INodeID pNodeID, T pObservation, long pObservationTimestamp) {
		return predict(pNodeID, pObservation, pObservationTimestamp, Time.getCurrentTime());
	}

	PredictionContainer<T> predict(INodeID pNodeID, T pObservation, long pObservationTimestamp,
			long pPredictionTimestamp);

	default PredictionContainer<T> predict(INodeID pNodeID) {
		return predict(pNodeID, Time.getCurrentTime());
	}

	default PredictionContainer<T> predict(INodeID pNodeID, long pPredictionTimestamp) {
		throw new UnsupportedOperationException();
	}

	default void addObservation(INodeID pNodeID, T pObservation, long pTimestamp) {
		predict(pNodeID, pObservation, pTimestamp);
	}

	default void clearData() {

	}

	SiSType<T> getBasicSiSType();
}
